@@ -1,11 +1,15 @@
 class Product:
+    parent_asin: str
     weight: float
     brand: str
     price_min: float
     price_max: float
     in_stock: bool
+    stock: int
     ship: str
     delivery: str
+    material: str
+    description: list
 
     def __init__(self, attrs=None):
         self.__dict__ = attrs or dict()
