@@ -8,14 +8,36 @@ from extreme_parser.amazon.product.model import Product
 from extreme_parser.util.parse import parse_number
 
 
+def product_overview_feature_div_table(selector: parsel.Selector, field: str) -> str:
+    table = selector.xpath("//div[@id='productOverview_feature_div']//table").get()
+    if table is None:
+        return ""
+    table = pandas.read_html(table)
+    if len(table) <= 0:
+        return ""
+    table = table[0].set_index(0)
+    if field not in table[1]:
+        return ""
+    s = table[1][field]
+    return s
+
+
 def parse(html: str, p: Product):
     sel = parsel.Selector(text=html)
+    parse_parent_asin(p, selector=sel)
     parse_weight(p, selector=sel)
     parse_brand(p, selector=sel)
     parse_price(p, selector=sel)
     parse_in_stock(p, selector=sel)
+    parse_stock(p, selector=sel)
     parse_ship(p, selector=sel)
     parse_delivery(p, selector=sel)
+    parse_material(p, selector=sel)
+    parse_description(p, selector=sel)
+
+
+def parse_parent_asin(p: Product, html: str = None, selector: parsel.Selector = None):
+    p.parent_asin = selector.re_first(r'"parentAsin":"(.+?)"')
 
 
 def parse_weight(p: Product, html: str = None, selector: parsel.Selector = None):
@@ -63,17 +85,7 @@ def parse_weight(p: Product, html: str = None, selector: parsel.Selector = None)
 
 def parse_brand(p: Product, html: str = None, selector: parsel.Selector = None):
     def s1() -> str:
-        table = selector.xpath("//div[@id='productOverview_feature_div']//table").get()
-        if table is None:
-            return ""
-        table = pandas.read_html(table)
-        if len(table) <= 0:
-            return ""
-        table = table[0].set_index(0)
-        if "Brand" not in table[1]:
-            return ""
-        s = table[1]["Brand"]
-        return s
+        return product_overview_feature_div_table(selector, "Brand")
 
     def s2() -> str:
         s = selector.xpath("//a[@id='bylineInfo']/text()").re_first("Brand: (.*)")
@@ -89,13 +101,17 @@ def parse_brand(p: Product, html: str = None, selector: parsel.Selector = None):
 
 
 def parse_price(p: Product, html: str = None, selector: parsel.Selector = None):
-    price_str = selector.xpath("//span[@id='priceblock_ourprice']/text()").get()
-    if price_str is None:
+    s = selector.xpath("//span[@id='priceblock_ourprice']/text()").get()
+    s = s or selector.xpath("//span[@id='priceblock_saleprice']/text()").get()
+    s = s or selector.xpath("//span[@id='priceblock_dealprice']/text()").get()
+    s = s or selector.xpath("//div[@id='buyNew_noncbb']/span/text()").get()
+    s = s or selector.xpath("//*[@id='color_name_0_price']/span/text()[last()]").get()
+    if s is None:
         p.price_min = None
         p.price_max = None
         return
 
-    prices: Union[None, list] = parse_number(price_str, first=False)
+    prices: Union[None, list] = parse_number(s, first=False)
     if prices is None or len(prices) == 0:
         p.price_min = None
         p.price_max = None
@@ -114,14 +130,32 @@ def parse_in_stock(p: Product, html: str = None, selector: parsel.Selector = Non
         return
 
     in_stock = in_stock.strip()
-    if in_stock == "In Stock.":
+    if (
+        in_stock == "In Stock." or
+        in_stock.startswith("Only") or
+        in_stock.startswith("Usually") or
+        in_stock.startswith("Available")
+    ):
         p.in_stock = True
-    elif in_stock in ["In stock soon.", "Currently unavailable."]:
+    elif in_stock in ["In stock soon.", "Currently unavailable.", "Temporarily out of stock.", ""]:
         p.in_stock = False
     else:
         p.in_stock = None
 
 
+def parse_stock(p: Product, html: str = None, selector: parsel.Selector = None):
+    stock = selector.xpath("//div[@id='availability']/span/text()").get()
+    if stock is None:
+        p.stock = None
+        return
+    stock = stock.strip()
+    if not stock.startswith("Only"):
+        p.stock = None
+        return
+
+    p.stock = parse_number(stock)
+
+
 def parse_ship(p: Product, html: str = None, selector: parsel.Selector = None):
     table = selector.xpath("//table[@id='tabular-buybox-container']").get()
     if table is None:
@@ -155,3 +189,23 @@ def parse_delivery(p: Product, html: str = None, selector: parsel.Selector = Non
         p.delivery = None
     else:
         p.delivery = delivery.group(1)
+
+
+def parse_material(p: Product, html: str = None, selector: parsel.Selector = None):
+    material = product_overview_feature_div_table(selector, "Material")
+    if material == "":
+        p.material = None
+    else:
+        p.material = material
+
+
+def parse_description(p: Product, html: str = None, selector: parsel.Selector = None):
+    texts = selector.xpath("//div[@id='feature-bullets']//li[not(@id)]/span/text()").getall()
+    if len(texts) < 1:
+        p.description = None
+        return
+
+    desc = list()
+    for t in texts:
+        desc.append(t.strip())
+    p.description = desc
